Bug 408143 Migrate website to git
diff --git a/downloads/extras-emf-query.php b/downloads/extras-emf-validation.php
similarity index 82%
rename from downloads/extras-emf-query.php
rename to downloads/extras-emf-validation.php
index 84b77fa..032f953 100644
--- a/downloads/extras-emf-query.php
+++ b/downloads/extras-emf-validation.php
@@ -11,10 +11,10 @@
  ****************************************************************************/
 
 $oldrels = array(
-	"1.1.0" => array("2007/06/20","http://archive.eclipse.org/modeling/emf/query/downloads/drops/1.1.0/R200706201159"),
-	"1.0.2" => array("2006/11/16","http://archive.eclipse.org/modeling/emf/query/downloads/drops/1.0.2/R200611161603"),
-	"1.0.1" => array("2006/09/25","http://archive.eclipse.org/modeling/emf/query/downloads/drops/1.0.1/R200609250852"),
-	"1.0.0" => array("2006/06/26","http://archive.eclipse.org/modeling/emf/query/downloads/drops/1.0.0/R200606261130"),
+	"1.1.0" => array("2007/06/20","http://archive.eclipse.org/modeling/emf/validation/downloads/drops/1.1.0/R200706201210"),
+	"1.0.2" => array("2006/11/16","http://archive.eclipse.org/modeling/emf/validation/downloads/drops/1.0.2/R200611161604"),
+	"1.0.1" => array("2006/09/25","http://archive.eclipse.org/modeling/emf/validation/downloads/drops/1.0.1/R200609250852"),
+	"1.0.0" => array("2006/06/26","http://archive.eclipse.org/modeling/emf/validation/downloads/drops/1.0.0/R200606261144"),
 );
 
 function showNotes()
diff --git a/_projectCommon.php b/_projectCommon.php
index f0d0561..1e65d90 100644
--- a/_projectCommon.php
+++ b/_projectCommon.php
@@ -8,19 +8,19 @@
 *
 * Contributors:
 *		Eclipse Foundation - Initial version
 *		Anthony Hunter - changes for EMF Query
 ********************************************************************************/
 $Nav->setLinkList(null);
 
-$projectname = "emf-query";
-$projectdisplayname = "EMF Query";
+$projectname = "emf-validation";
+$projectdisplayname = "EMF Validation";
 $modelingprojectname = "modeling";
 $topprojectname = "emf"; 
-$shortprojectname = "query";
+$shortprojectname = "validation";
 
 $debug = (isset ($_GET["debug"]) && preg_match("/^\d+$/", $_GET["debug"]) ? $_GET["debug"] : -1);
 
-include_once($_SERVER["DOCUMENT_ROOT"] . "/emf-query/downloads/scripts.php");
+include_once($_SERVER["DOCUMENT_ROOT"] . "/emf-validation/downloads/scripts.php");
 
 $regs = null;
 $buildtypes = array(
@@ -44,30 +44,30 @@
 # $Nav->setLinkList(array());
 
 # Break the navigation into sections
-$Nav->addNavSeparator("EMF Query", 	"/emf-query");
-$Nav->addCustomNav("Downloads", "/emf-query/downloads.php", "_self", 3);
-$Nav->addCustomNav("Documentation", "/emf-query/documentation.php", "_self", 3);
+$Nav->addNavSeparator("EMF Validation", 	"/emf-validation");
+$Nav->addCustomNav("Downloads", "/emf-validation/downloads.php", "_self", 3);
+$Nav->addCustomNav("Documentation", "/emf-validation/documentation.php", "_self", 3);
 $Nav->addCustomNav("Wiki", "http://wiki.eclipse.org/EMF", "_self", 3);
-$Nav->addCustomNav("Support", "/emf-query/support.php", "_self", 3);
+$Nav->addCustomNav("Support", "/emf-validation/support.php", "_self", 3);
 $Nav->addCustomNav("Newsgroup", "http://dev.eclipse.org/newslists/news.eclipse.modeling.emf/maillist.html", "_self", 3);
 $Nav->addCustomNav("Mailing List", "https://dev.eclipse.org/mailman/listinfo/emf-dev", "_self", 3);
 $Nav->addCustomNav("Modeling Corner", "http://wiki.eclipse.org/Modeling_Corner", "_self", 3);
 
 # Define keywords, author and title here, or in each PHP page specifically
-$pageKeywords	= "eclipse, emf, emf query";
+$pageKeywords	= "eclipse, emf, emf validation";
 $pageAuthor		= "Anthony Hunter";
 
 # top navigation bar
 # To override and replace the navigation with your own, uncomment the line below.
 $Menu->setMenuItemList(array());
 $Menu->addMenuItem("Eclipse", "/", "_self");
-$Menu->addMenuItem("EMF Query", "/emf-query", "_self");
-$Menu->addMenuItem("Downloads", "/emf-query/downloads.php", "_self");
-$Menu->addMenuItem("Documentation", "/emf-query/documentation.php", "_self");
-$Menu->addMenuItem("About", "http://www.eclipse.org/projects/project_summary.php?projectid=modeling.emf.emf-query", "_self");
+$Menu->addMenuItem("EMF Validation", "/emf-validation", "_self");
+$Menu->addMenuItem("Downloads", "/emf-validation/downloads.php", "_self");
+$Menu->addMenuItem("Documentation", "/emf-validation/documentation.php", "_self");
+$Menu->addMenuItem("About", "http://www.eclipse.org/projects/project_summary.php?projectid=modeling.emf.emf-validation", "_self");
 
 # To define additional CSS or other pre-body headers
-$App->AddExtraHtmlHeader('<link rel="stylesheet" type="text/css" href="/emf-query/style.css"/>');
+$App->AddExtraHtmlHeader('<link rel="stylesheet" type="text/css" href="/emf-validation/style.css"/>');
 
 # To enable occasional Eclipse Foundation Promotion banners on your pages (EclipseCon, etc)
 $App->Promotion = TRUE;
@@ -8,19 +8,19 @@
 * Contributors:
 *		Eclipse Foundation - Initial version
-*		Anthony Hunter - changes for EMF Query
+*		Anthony Hunter - changes for EMF Validation
 ********************************************************************************/
 $Nav->setLinkList(null);
diff --git a/documentation.php b/documentation.php
index ef440ae..542cb47 100644
--- a/documentation.php
+++ b/documentation.php
@@ -8,7 +8,7 @@
 *
 * Contributors:
 *		Eclipse Foundation - Initial version
 *		Anthony Hunter - changes for EMF Query
 ********************************************************************************/
 require_once($_SERVER['DOCUMENT_ROOT'] . "/eclipse.org-common/system/app.class.php");
 require_once($_SERVER['DOCUMENT_ROOT'] . "/eclipse.org-common/system/nav.class.php");
@@ -18,8 +18,8 @@
 $Menu = new Menu();
 include($App->getProjectCommon());
 
-$pageTitle 		= "EMF Query Documentation";
-$App->AddExtraHtmlHeader('<link rel="stylesheet" type="text/css" href="/emf-query/style.css"/>');
+$pageTitle 		= "EMF Validation Documentation";
+$App->AddExtraHtmlHeader('<link rel="stylesheet" type="text/css" href="/emf-validation/style.css"/>');
 
 $html  = <<<EOHTML
 <div id="midcolumn">
@@ -8,7 +8,7 @@
 * Contributors:
 *		Eclipse Foundation - Initial version
-*		Anthony Hunter - changes for EMF Query
+*		Anthony Hunter - changes for EMF Validation
 ********************************************************************************/
 require_once($_SERVER['DOCUMENT_ROOT'] . "/eclipse.org-common/system/app.class.php");
diff --git a/downloads.php b/downloads.php
index 1d65d5f..fe361c5 100644
--- a/downloads.php
+++ b/downloads.php
@@ -8,7 +8,7 @@
 *
 * Contributors:
 *		Eclipse Foundation - Initial version
 *		Anthony Hunter - changes for EMF Query
 ********************************************************************************/
 require_once($_SERVER['DOCUMENT_ROOT'] . "/eclipse.org-common/system/app.class.php");
 require_once($_SERVER['DOCUMENT_ROOT'] . "/eclipse.org-common/system/nav.class.php");
@@ -18,8 +18,8 @@
 $Menu = new Menu();
 include($App->getProjectCommon());
 
-$pageTitle = "EMF Query Downloads";
-$App->AddExtraHtmlHeader('<link rel="stylesheet" type="text/css" href="/emf-query/style.css"/>');
+$pageTitle = "EMF Validation Downloads";
+$App->AddExtraHtmlHeader('<link rel="stylesheet" type="text/css" href="/emf-validation/style.css"/>');
 
 $html  = <<<EOHTML
 <div id="midcolumn">
@@ -29,18 +29,18 @@
 unless otherwise specified.</p>
 
 <h3>Installation via Eclipse Update Manager</h3>
-<p>Using the Eclipse Update Manager (see <a href="http://help.eclipse.org/juno/index.jsp?topic=/org.eclipse.platform.doc.user/tasks/tasks-129.htm">Eclipse Help</a> for detailed instructions) EMF Query can be installed from the following update sites:
+<p>Using the Eclipse Update Manager (see <a href="http://help.eclipse.org/juno/index.jsp?topic=/org.eclipse.platform.doc.user/tasks/tasks-129.htm">Eclipse Help</a> for detailed instructions) EMF Validation can be installed from the following update sites:
 <ul>
-	<li>Releases: <a href="http://download.eclipse.org/modeling/emf/query/updates/releases/">http://download.eclipse.org/modeling/emf/query/updates/releases/</a></li>
-	<li>Milestones: <a href="http://download.eclipse.org/modeling/emf/query/updates/milestones/">http://download.eclipse.org/modeling/emf/query/updates/milestones/</a></li>
-	<li>Integration: <a href="http://download.eclipse.org/modeling/emf/query/updates/interim/">http://download.eclipse.org/modeling/emf/query/updates/interim/</a></li>
+	<li>Releases: <a href="http://download.eclipse.org/modeling/emf/validation/updates/releases/">http://download.eclipse.org/modeling/emf/validation/updates/releases/</a></li>
+	<li>Milestones: <a href="http://download.eclipse.org/modeling/emf/validation/updates/milestones/">http://download.eclipse.org/modeling/emf/validation/updates/milestones/</a></li>
+	<li>Integration: <a href="http://download.eclipse.org/modeling/emf/validation/updates/interim/">http://download.eclipse.org/modeling/emf/validation/updates/interim/</a></li>
 </ul>
 
 <h3>Downloadable P2 Repositories and SDK dropins</h3>
 <p>If you prefer an update-site or an SDK archive, you can download it from <a href="downloads/index.php">here directly</a>.</p>
 
 <h3>Nightly Builds</h3>
-<p>The nightly builds can also be used as a P2 repository. The nightly builds for the Luna simultaneous release can be accessed from <a href="https://hudson.eclipse.org/query/job/emf-query-master/">Hudson</a>.</p>
+<p>The nightly builds can also be used as a P2 repository. The nightly builds for the Luna simultaneous release can be accessed from <a href="https://hudson.eclipse.org/validation/job/emf-validation-master/">Hudson</a>.</p>
 
 <h3>Translations</h3>
 <p>Translations packages can be downloaded from the <a href="http://www.eclipse.org/babel/downloads.php">Babel project downloads page</a>.</p>
@@ -8,7 +8,7 @@
 * Contributors:
 *		Eclipse Foundation - Initial version
-*		Anthony Hunter - changes for EMF Query
+*		Anthony Hunter - changes for EMF Validation
 ********************************************************************************/
 require_once($_SERVER['DOCUMENT_ROOT'] . "/eclipse.org-common/system/app.class.php");
diff --git a/getting_involved.php b/getting_involved.php
index 596b6d6..0013491 100644
--- a/getting_involved.php
+++ b/getting_involved.php
@@ -8,7 +8,7 @@
 *
 * Contributors:
 *		Eclipse Foundation - Initial version
 *		Anthony Hunter - changes for EMF Query
 ********************************************************************************/
 require_once($_SERVER['DOCUMENT_ROOT'] . "/eclipse.org-common/system/app.class.php");
 require_once($_SERVER['DOCUMENT_ROOT'] . "/eclipse.org-common/system/nav.class.php");
@@ -18,14 +18,14 @@
 $Menu = new Menu();
 include($App->getProjectCommon());
 
-$pageTitle 		= "EMF Query Getting Involved";
-$App->AddExtraHtmlHeader('<link rel="stylesheet" type="text/css" href="/emf-query/style.css"/>');
+$pageTitle 		= "EMF Validation Getting Involved";
+$App->AddExtraHtmlHeader('<link rel="stylesheet" type="text/css" href="/emf-validation/style.css"/>');
 
 $html  = <<<EOHTML
 <div id="midcolumn">
 <h2>$pageTitle</h2>
 
-<p>As every Eclipse project, EMF Query is strongly dependent on active support by its community.
+<p>As every Eclipse project, EMF Validation is strongly dependent on active support by its community.
 You may become part of that community and get involved by reporting bugs or enhancement request,
 by contributing patches, by participation in discussions on the mailing list, or by supporting the
 maintaining of the EMF wiki.</p>
@@ -8,7 +8,7 @@
 * Contributors:
 *		Eclipse Foundation - Initial version
-*		Anthony Hunter - changes for EMF Query
+*		Anthony Hunter - changes for EMF Validation
 ********************************************************************************/
 require_once($_SERVER['DOCUMENT_ROOT'] . "/eclipse.org-common/system/app.class.php");
diff --git a/index.php b/index.php
index 1d4a695..297501d 100644
--- a/index.php
+++ b/index.php
@@ -8,7 +8,7 @@
 *
 * Contributors:
 *		Eclipse Foundation - Initial version
 *		Anthony Hunter - changes for EMF Query
 ********************************************************************************/
 require_once($_SERVER['DOCUMENT_ROOT'] . "/eclipse.org-common/system/app.class.php");
 require_once($_SERVER['DOCUMENT_ROOT'] . "/eclipse.org-common/system/nav.class.php");
@@ -20,7 +20,7 @@
 
 $localVersion = false;
 
-$pageTitle 		= "Eclipse EMF Query";
+$pageTitle 		= "Eclipse EMF Validation";
 
 // 	# Paste your HTML content between the EOHTML markers!
 $html = <<<EOHTML
@@ -39,23 +39,17 @@
 </div>
 
 <div id="midcolumn">
-<h3>Eclipse Modeling Framework (EMF) Model Query</h3>
+<h3>Eclipse Modeling Framework (EMF) Model Validation</h3>
 
 <div id="introText">
-
-<p>EMF model query facilitates the process of search and retrieval of model elements of interest in a flexible yet controlled and structured manner. Provides API support for the basic EObject based Condition objects that are used to formulate queries for EMF models.</p>
-<p>EMF model query provides the following classes/interfaces to support queries.</p>
-<p><ol>
-	<li>The IEObjectSource interface provides the search scope elements to be used in a query.</li>
-	<li>The SELECT class implements a template-function that does the iteration over model elements and applies the search condition on each; it collects the resulting elements into a QueryResultSet object and returns it to the caller.</li>
-	<li>The FROM class represents the elements to search. It is responsible of providing an appropriate iterator for the elements in the search space.</li>
-	<li>The WHERE class applies the search conditions over the elements in the search set.</li>
-	<li>The UPDATE class passes the elements who satisfy the search condition to a caller-supplied modification function. It collects the modified elements into a QueryResultSet object and returns it to the caller.</li>
-	<li>The QueryResultSet class represents the set of elements returned by a given query.</li>
-	<li>The EObjectCondition class is the abstract parent of all conditions that deal with model-elements (i.e., EObjects). It incorporates the services of a PruneHandler in order to answers whether or not to prune the element tree at a specific element and thus ignore its children.</li>
-	<li>The ConditionPolicy class is used to allow the user to decide how to apply a given condition on a collection of a model-element EAttributes or EReferences values. Supports both the: exists (ANY) and for-all (ALL) semantics.</li>
-	<li>The EObjectStructuralFeatureValueCondition class is the parent class for conditions that are responsible for checking the values held in model-elements attributes or references.</li>
-</ol></p>
+<p>EMF model validation provides the following capabilities:</p>
+<ol>
+	<li>Constraint Definition  - Provides API for defining constraints for any EMF meta-model (batch and live constraints).</li>
+	<li>Customizable model traversal algorithms - Extensibility API to support meta-models that require custom strategies for model traversal.</li>
+	<li>Constraint parsing for languages - Provides support for parsing the content of constraint elements defined in specific languages. The validation framework provides support for two languages: Java and OCL.</li>
+	<li>Configurable constraint bindings to application contexts - API support to define "client contexts" that describe the objects that need to be validated and to bind them to constraints that need to be enforced on these objects.</li>
+	<li>Validation listeners - Support for listening to validation events.</li>
+</ol>
 
 </div>
 
@@ -65,12 +59,12 @@
 
 <div>
 <h3>Current Status</h3>
-<p>Development is underway for the proposed EMF Query 1.8.0 release for Eclipse Luna, due June 2014.</p>
+<p>Development is underway for the proposed EMF Validation 1.8.0 release for Eclipse Luna, due June 2014.</p>
 </div>
 
 <div id="headlines">
-<h3>EMF Query 1.7.0 Now Available</h3>
-<p><i>June 26, 2013 -</i> EMF Query 1.7.0 for Eclipse Kepler has been released. Check the <a href="/emf-query/downloads.php">Download</a> page.</p>
+<h3>EMF Validation 1.7.0 Now Available</h3>
+<p><i>June 26, 2013 -</i> EMF Validation 1.7.0 for Eclipse Kepler has been released. Check the <a href="/emf-validation/downloads.php">Download</a> page.</p>
 </div>
 
 </div>
@@ -8,7 +8,7 @@
 * Contributors:
 *		Eclipse Foundation - Initial version
-*		Anthony Hunter - changes for EMF Query
+*		Anthony Hunter - changes for EMF Validation
 ********************************************************************************/
 require_once($_SERVER['DOCUMENT_ROOT'] . "/eclipse.org-common/system/app.class.php");
diff --git a/support.php b/support.php
index ae82c5b..b069dde 100644
--- a/support.php
+++ b/support.php
@@ -8,7 +8,7 @@
 *
 * Contributors:
 *		Eclipse Foundation - Initial version
 *		Anthony Hunter - changes for EMF Query
 ********************************************************************************/
 require_once($_SERVER['DOCUMENT_ROOT'] . "/eclipse.org-common/system/app.class.php");
 require_once($_SERVER['DOCUMENT_ROOT'] . "/eclipse.org-common/system/nav.class.php");
@@ -18,16 +18,16 @@
 $Menu = new Menu();
 include($App->getProjectCommon());
 
-$pageTitle 		= "EMF Query Support";
-$App->AddExtraHtmlHeader('<link rel="stylesheet" type="text/css" href="/emf-query/style.css"/>');
+$pageTitle 		= "EMF Validation Support";
+$App->AddExtraHtmlHeader('<link rel="stylesheet" type="text/css" href="/emf-validation/style.css"/>');
 
 $html  = <<<EOHTML
 <div id="midcolumn">
 <h2>$pageTitle</h2>
-<p>EMF Query support is provided by the community on a volunteer basis. You may use the following means to reach this community.</p>
+<p>EMF Validation support is provided by the community on a volunteer basis. You may use the following means to reach this community.</p>
 
 <h3>Frequently Asked Questions (FAQs)</h3>
-<p>For frequently asked questions and known pitfalls please refer to the <a href="http://wiki.eclipse.org/EMF-Query-FAQ">EMF Query FAQ</a>. You might also consider the
+<p>For frequently asked questions and known pitfalls please refer to the <a href="http://wiki.eclipse.org/EMF-Validation-FAQ">EMF Validation FAQ</a>. You might also consider the
 the <a href="http://wiki.eclipse.org/EMF/FAQ">EMF FAQ</a> or the <a href="http://wiki.eclipse.org/index.php/Eclipse_FAQs">Eclipse FAQs</a>.
 </p>
@@ -8,7 +8,7 @@
 * Contributors:
 *		Eclipse Foundation - Initial version
-*		Anthony Hunter - changes for EMF Query
+*		Anthony Hunter - changes for EMF Validation
 ********************************************************************************/
 require_once($_SERVER['DOCUMENT_ROOT'] . "/eclipse.org-common/system/app.class.php");